# Empiric!

The python package `Empiric!` provides an easy-to-use framework to conduct empirical experiments, with a particular focus on geospatial data perception and contribution.

## Installation

To install `Empiric`, you will need `python3` and `pip` ([How to install pip](https://pip.pypa.io/en/stable/installing/)). Then execute:
```bash
pip install Empiric
```
On some operating systems, `pip` for `python3` will be named `pip3`:
```bash
pip3 install Empiric
```

## Author

This software is written and maintained by Franz-Benjamin Mocnik, <mail@mocnik-science.net>.

(c) by Franz-Benjamin Mocnik, 2020.

## License

The code is licensed under the [GPL-3](https://github.com/mocnik-science/empiric/blob/master/LICENSE).
